@@ -20,6 +20,10 @@
 # with this application; if not, write to the Free Software Foundation, Inc., 51
 # Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+import string
+import subprocess
+from NvidiaDetector.nvidiadetector import NvidiaDetection
+
 ####################
 # Type dictionaries: different installation types possible
 def get_install_type_dictionary(self):
@@ -72,7 +76,6 @@ def get_community_theme_dictionary(self):
 def get_frontend_plugin_dictionary(self):
     list = {
         "mytharchive": self.mytharchive_checkbox,                              \
-        "mythbrowser": self.mythbrowser_checkbox,                              \
         "mythcontrols": self.mythcontrols_checkbox,                            \
         "mythflix": self.mythflix_checkbox,                                    \
         "mythgame": self.mythgame_checkbox,                                    \
@@ -93,6 +96,13 @@ def get_backend_plugin_dictionary(self):
 ####################
 #Other dictionaries: these are for managing a list of all other apps
 ####################
+def get_role_dictionary(self):
+    list = {
+        "mythtv-backend-master": self.primary_backend_radio,                   \
+        "mythtv-backend":        self.secondary_backend_radio,                 \
+        "mythtv-frontend":       self.frontend_radio }
+    return list
+
 def get_desktop_dictionary(self):
     list = {
         "ubuntu-desktop": self.ubuntu_desk_check,                              \
@@ -130,13 +140,32 @@ def get_diskless_dictionary(self):
         "dhcp3-server": self.diskless_server_dhcp }
     return list
 
+def get_artwork_dictionary(self):
+    list = {
+        "mythbuntu-gdm-theme": self.gdm_theme,                                 \
+        "gtk2-engines-mythbuntu": self.gtk_theme,                              \
+        "mythbuntu-default-settings": self.xfce_theme,                         \
+        "mythbuntu-artwork-usplash": self.splash_theme }
+    return list
 
 def get_graphics_dictionary():
-    list =  {
-#        "NVIDIA 71 Series" : "nvidia-glx-71", \
-#        "NVIDIA 96 Series" : "nvidia-glx-96", \
-        "NVIDIA 173 Series" : "nvidia-glx-173", \
-        "NVIDIA 177 Series" : "nvidia-glx-177", \
-        "AMD Proprietary" : "xorg-driver-fglrx", \
-        "Hauppauge PVR-350 (ivtv)" : "xserver-xorg-video-ivtv" }
+    list = {}
+    #AMD graphics detection
+    output=string.split(subprocess.Popen(['lspci'],stdout=subprocess.PIPE).communicate()[0],'\n')
+    for line in output:
+        if line and 'VGA' in line and ('AMD' in line or 'ATI' in line):
+            list["AMD Graphics"]="xorg-driver-fglrx"
+            break
+
+    #NVIDIA Graphics detection
+    nv = NvidiaDetection().selectDriver()
+    if nv is not None:
+        list["NVIDIA Graphics"]=nv
+    return list
+
+def get_tweak_dictionary(self):
+    list = {
+        "/etc/mysql/conf.d/mythtv-tweaks.cnf": self.enable_mysql_tweaks, \
+        "/etc/cron.daily/mythtv-xfs-defrag": self.enable_nightly_defrag, \
+        "/etc/cron.daily/optimize_mythdb": self.enable_mysql_repair}
     return list
